@@ -1,4 +1,4 @@
-/* $Id: colors.c,v 5.0 2001/04/07 20:00:58 dik Exp $
+/* $Id: colors.c,v 5.1 2001/05/08 11:35:29 bertg Exp $
  *
  * XPilot, a multiplayer gravity war game.  Copyright (C) 1991-2001 by
  *
@@ -54,12 +54,6 @@
 char colors_version[] = VERSION;
 
 
-#ifndef	lint
-static char sourceid[] =
-    "@(#)$Id: colors.c,v 5.0 2001/04/07 20:00:58 dik Exp $";
-#endif
-
-
 /* Kludge for visuals under C++ */
 #if defined(__cplusplus)
 #define class c_class
