@@ -1,4 +1,4 @@
-/* $Id: dbuff.c,v 5.0 2001/04/07 20:00:58 dik Exp $
+/* $Id: dbuff.c,v 5.1 2001/05/08 11:35:29 bertg Exp $
  *
  * XPilot, a multiplayer gravity war game.  Copyright (C) 1991-2001 by
  *
@@ -44,10 +44,6 @@
 char dbuff_version[] = VERSION;
 
 
-#ifndef	lint
-static char sourceid[] =
-    "@(#)$Id: dbuff.c,v 5.0 2001/04/07 20:00:58 dik Exp $";
-#endif
 
 
 #ifdef SPARC_CMAP_HACK
