@@ -1,4 +1,4 @@
-/* $Id: record.c,v 5.3 2001/06/02 21:01:03 bertg Exp $
+/* $Id: record.c,v 5.4 2001/10/19 17:52:56 bertg Exp $
  *
  * XPilot, a multiplayer gravity war game.  Copyright (C) 1991-2001 by
  *
@@ -35,10 +35,13 @@
 # include <X11/Xlib.h>
 # include <X11/Xutil.h>
 # include <X11/Xos.h>
+#else
+# include <fcntl.h>
 #endif
 
 #ifdef _WINDOWS
-#include "winX.h"
+# include "winX.h"
+# include "winX_.h"
 #endif
 
 #include "version.h"
@@ -88,8 +91,13 @@ static int		record_dash_dirty = 0;	/* Has dashes list changed? */
  */
 static void Dummy_newFrame(void) {}
 static void Dummy_endFrame(void) {}
+
+#ifdef _WINDOWS
+extern void paintItemSymbol(unsigned char type, Drawable drawable, GC mygc, int x, int y, int color);
+#else
 static void Dummy_paintItemSymbol(unsigned char type, Drawable drawable,
 				  GC mygc, int x, int y, int color) {}
+#endif
 
 extern char	hostname[];
 
@@ -192,9 +200,15 @@ static void RWriteHeader(void)
     putc(maxColors, recordFP);
     for (i = 0; i < maxColors; i++) {
 	RWriteULong(colors[i].pixel);
+#ifdef _WINDOWS
+	RWriteUShort(256*GetRValue(objs[i].color));
+	RWriteUShort(256*GetGValue(objs[i].color));
+	RWriteUShort(256*GetBValue(objs[i].color));
+#else
 	RWriteUShort(colors[i].red);
 	RWriteUShort(colors[i].green);
 	RWriteUShort(colors[i].blue);
+#endif
     }
     RWriteString(gameFontName);
     RWriteString(messageFontName);
@@ -227,6 +241,7 @@ static int RGetPixelIndex(unsigned long pixel)
 
 static void RWriteTile(Pixmap tile)
 {
+#ifndef _WINDOWS
     typedef struct tile_list {
 	struct tile_list	*next;
 	Pixmap			tile;
@@ -286,6 +301,7 @@ static void RWriteTile(Pixmap tile)
     XDestroyImage(img);
 
     next_tile_id++;
+#endif
 }
 
 static void RWriteGC(GC gc, unsigned long req_mask)
@@ -655,6 +671,9 @@ static int RFillPolygon(Display *display, Drawable drawable, GC gc,
 static void RPaintItemSymbol(unsigned char type, Drawable drawable, GC mygc,
 			     int x, int y, int color)
 {
+#ifdef _WINDOWS
+	paintItemSymbol(type, drawable, mygc, x, y, color);
+#endif
     if (drawable == p_draw) {
 	putc(RC_PAINTITEMSYMBOL, recordFP);
 	RWriteGC(gc, GCForeground | GCBackground);
@@ -776,7 +795,11 @@ static struct recordable_drawing Xdrawing = {
     (draw_string_proto_t)XDrawString,
     XFillArc,
     XFillPolygon,
+#ifdef _WINDOWS
+    paintItemSymbol,
+#else
     Dummy_paintItemSymbol,
+#endif
     XFillRectangle,
     XFillRectangles,
     XDrawArcs,
@@ -830,6 +853,9 @@ long Record_size(void)
  */
 void Record_toggle(void)
 {
+#if !(defined(_WINDOWS) && defined(PENS_OF_PLENTY))
+/* No recording available with PEN_OF_PLENTY under Windows.
+*/
     if (record_filename != NULL) {
 	if (!record_start) {
 	    record_start = True;
@@ -841,6 +867,9 @@ void Record_toggle(void)
 		    record_start = False;
 		} else {
 		    setvbuf(recordFP, NULL, _IOFBF, (size_t)(8 * 1024));
+# ifdef _WINDOWS
+			setmode(fileno(recordFP), O_BINARY);
+# endif
 		}
 	    }
 	} else {
@@ -853,6 +882,7 @@ void Record_toggle(void)
 	    recording = False;
 	}
     }
+#endif
 }
 
 /*
